@@ -1,12 +1,15 @@
 from quickstats._version import __version__
 from quickstats.decorators import *
 
+import os
 import pathlib
 
 import ROOT
 ROOT.gROOT.SetBatch(True) 
 ROOT.PyConfig.IgnoreCommandLineOptions = True
-macro_path = pathlib.Path(__file__).parent.absolute()
+module_path = pathlib.Path(__file__).parent.absolute()
+macro_path = module_path
+stylesheet_path = os.path.join(module_path, 'stylesheets')
 
 MAX_WORKERS = 8
 
