@@ -1,10 +1,10 @@
 from typing import Optional, Union, List
 
 from quickstats import _PRINT_
-from quickstats.components import ExtendedModel, ExtendedMinimizer
+from quickstats.components import AbstractObject, ExtendedModel, ExtendedMinimizer
 import ROOT
 
-class AnalysisObject(object):
+class AnalysisObject(AbstractObject):
     def __init__(self, filename:Optional[str]=None, data_name:str='combData', binned_likelihood:bool=True,
                  fix_param:str='', profile_param:str='', ws_name:Optional[str]=None, 
                  mc_name:Optional[str]=None, snapshot_name:Optional[Union[List[str], str]]=None,
@@ -13,8 +13,8 @@ class AnalysisObject(object):
                  num_cpu:int=1, offset:bool=True, optimize:int=2, eigen:bool=False,
                  fix_cache:bool=True, fix_multi:bool=True, max_calls:int=-1, 
                  max_iters:int=-1, constrain_nuis:bool=True, batch_mode:bool=False,
-                 int_bin_precision:float=-1., verbosity:Union[int, str]="INFO", **kwargs):
-
+                 int_bin_precision:float=-1., verbosity:Optional[Union[int, str]]="INFO", **kwargs):
+        super().__init__(verbosity=verbosity)
         self.model = None
         self.minimizer = None
         
@@ -31,11 +31,11 @@ class AnalysisObject(object):
     def setup_model(self, filename, data_name='combData', binned_likelihood:bool=True, 
                     ws_name:Optional[str]=None, mc_name:Optional[str]=None, 
                     snapshot_name:Optional[str]=None, fix_cache:bool=True, 
-                    fix_multi:bool=True):
+                    fix_multi:bool=True, verbosity:Optional[Union[int, str]]="INFO"):
         
         model = ExtendedModel(fname=filename, ws_name=ws_name, mc_name=mc_name, data_name=data_name, 
                               snapshot_name=snapshot_name, binned_likelihood=binned_likelihood,
-                              fix_cache=fix_cache, fix_multi=fix_multi)
+                              fix_cache=fix_cache, fix_multi=fix_multi, verbosity=verbosity)
         self.model = model
     
     def setup_parameters(self, fix_param:str='', profile_param:str=''):
@@ -50,9 +50,10 @@ class AnalysisObject(object):
                         precision:float=0.001, eps:float=1.0, strategy:int=0, 
                         num_cpu:int=1, offset:bool=True, optimize:bool=True, eigen:bool=False,
                         max_calls:int=-1, max_iters:int=-1, print_level:int=-1, timer:bool=False,
-                        constrain_nuis:bool=True, batch_mode:bool=False, int_bin_precision:float=-1.):
+                        constrain_nuis:bool=True, batch_mode:bool=False, int_bin_precision:float=-1.,
+                        verbosity:Optional[Union[int, str]]="INFO"):
         
-        minimizer = ExtendedMinimizer("Minimizer", self.model.pdf, self.model.data)
+        minimizer = ExtendedMinimizer("Minimizer", self.model.pdf, self.model.data, verbosity=verbosity)
         
         nll_commands = [ROOT.RooFit.NumCPU(num_cpu, 3), 
                         ROOT.RooFit.Offset(offset)]
