@@ -22,6 +22,7 @@ class AsimovGenerator(AnalysisObject):
     ASIMOV_SETTINGS = {
         AsimovType.S_NP_Nom: {
             "asimov_name": "asimovData_0_NP_Nominal",
+            "asimov_snapshot": "asimovData_0_NP_Nominal",
             "poi_val": 1,
             "poi_profile": 1,
             "do_fit": False,
@@ -29,6 +30,7 @@ class AsimovGenerator(AnalysisObject):
         },
         AsimovType.B_NP_Nom: {
             "asimov_name": "asimovData_1_NP_Nominal",
+            "asimov_snapshot": "asimovData_1_NP_Nominal",
             "poi_val": 0,
             "poi_profile": 0,
             "do_fit": False,
@@ -36,6 +38,7 @@ class AsimovGenerator(AnalysisObject):
         },
         AsimovType.B_NP_Fit: {
             "asimov_name": "asimovData_0_NP_Profile",
+            "asimov_snapshot": "asimovData_0_NP_Profile",
             "poi_val": 0,
             "poi_profile": 0,
             "do_fit": True,
@@ -43,6 +46,7 @@ class AsimovGenerator(AnalysisObject):
         },
         AsimovType.S_NP_Fit: {
             "asimov_name": "asimovData_1_NP_Profile",
+            "asimov_snapshot": "asimovData_1_NP_Profile",
             "poi_val": 1,
             "poi_profile": 1,
             "do_fit": True,
@@ -50,6 +54,7 @@ class AsimovGenerator(AnalysisObject):
         },
         AsimovType.S_NP_Fit_muhat: {
             "asimov_name": "asimovData_muhat_NP_Profile",
+            "asimov_snapshot": "asimovData_muhat_NP_Profile",
             "poi_val": 1,
             "poi_profile": None,
             "do_fit": True,
@@ -57,6 +62,7 @@ class AsimovGenerator(AnalysisObject):
         },
         AsimovType.B_unconstrained_NP_Fit: {
             "asimov_name": "asimovData_0_unconstrained_NP_Profile",
+            "asimov_snapshot": "asimovData_0_unconstrained_NP_Profile",
             "poi_val": 0,
             "poi_profile": 0,
             "do_fit": True,
@@ -65,6 +71,7 @@ class AsimovGenerator(AnalysisObject):
         },
         AsimovType.S_unconstrained_NP_Fit: {
             "asimov_name": "asimovData_1_unconstrained_NP_Profile",
+            "asimov_snapshot": "asimovData_1_unconstrained_NP_Profile",
             "poi_val": 1,
             "poi_profile": 1,
             "do_fit": True,
@@ -73,6 +80,7 @@ class AsimovGenerator(AnalysisObject):
         },
         AsimovType.S_unconstrained_NP_Fit_muhat: {
             "asimov_name": "asimovData_muhat_unconstrained_NP_Profile",
+            "asimov_snapshot": "asimovData_muhat_unconstrained_NP_Profile",
             "poi_val": 1,
             "poi_profile": None,
             "do_fit": True,
