@@ -170,9 +170,15 @@ class AsymptoticCLs(AnalysisObject):
             self.load_snapshot(snapshot_name)
         else:
             raise RuntimeError('Failed to load snapshot for nll "{}"'.format(nll.GetName()))
+        if Verbosity.DEBUG >= self.stdout.verbosity:
+            self.stdout.debug("DEBUG: Before Fit ----------------------------------------------")
+            self.model.print_summary(items=['poi', 'nuisance_parameter', 'global_observable'])             
         self.global_status += self.minimizer.minimize(nll)
         self.minimizer_calls += 1
         nll_val = nll.getVal()
+        if Verbosity.DEBUG >= self.stdout.verbosity:
+            self.stdout.debug("DEBUG: After Fit ----------------------------------------------")
+            self.model.print_summary(items=['poi', 'nuisance_parameter', 'global_observable'])          
         self.load_snapshot(self.nom_glob_name)
         return nll_val
     
@@ -187,8 +193,6 @@ class AsymptoticCLs(AnalysisObject):
         self.poi.setConstant(1)
         self.set_poi_value(mu)
         nll_value = self.get_nll_val(nll)
-        if Verbosity.DEBUG >= self.stdout.verbosity:
-            self.model.print_summary(items=['nuisance_parameter', 'global_observable'])        
         self.poi.setConstant(is_const)
         qmu = 2*(nll_value - nll_muhat)
         if qmu < 0 :
