@@ -5,9 +5,11 @@ import math
 import json
 from itertools import repeat
 
+from quickstats import semistaticmethod
 from quickstats.components import AbstractObject, ExtendedModel
 from quickstats.components.numerics import str_encode_value
 from quickstats.utils.common_utils import execute_multi_tasks
+from quickstats.utils.root_utils import load_macro
 from quickstats.utils.roostats_utils import process_hypotest_results, merge_toy_results
 
 import ROOT
@@ -34,7 +36,7 @@ class ToyLimitCalculator(AbstractObject):
                  verbosity:Optional[Union[int, str]]=None,
                  hypotest_options:Optional[Dict]=None,
                  mode:str='toy',
-                 teststat_cls=None):
+                 use_custom_teststat_cls:bool=True):
         super().__init__(verbosity=verbosity)
         
         self.model_base = ExtendedModel(filename,
@@ -80,7 +82,10 @@ class ToyLimitCalculator(AbstractObject):
         pdf_SB = self.model_SB.GetPdf()
         globs_SB = self.model_SB.GetGlobalObservables()
         
-        if teststat_cls is None:
+        if use_custom_teststat_cls:
+            self.load_extension()
+            teststat_cls = ROOT.RooStats.ProfileLikelihoodTestStatEx
+        else:
             teststat_cls = ROOT.RooStats.ProfileLikelihoodTestStat
         self.plr = teststat_cls(pdf_SB)
         self.plr.SetGlobalObservables(globs_SB)
@@ -122,6 +127,17 @@ class ToyLimitCalculator(AbstractObject):
         
         self.reset_results()
         
+
+    @semistaticmethod
+    def load_extension(self):
+        try:
+            if not hasattr(ROOT, 'ProfileLikelihoodTestStatEx'):
+                result = load_macro('ProfileLikelihoodTestStatEx')
+                if hasattr(ROOT, 'ProfileLikelihoodTestStatEx'):
+                    self.stdout.info('INFO: Loaded extension module "ProfileLikelihoodTestStatEx"')
+        except Exception as e:
+            print(e)        
+        
     def reset_results(self):
         result = ROOT.RooStats.HypoTestInverterResult("result", self.poi, 0.95)
         result.SetConfidenceLevel(0.95)
